summaryrefslogtreecommitdiffstats
path: root/common
diff options
context:
space:
mode:
authorDaisuke Miyakawa <dmiyakawa@google.com>2011-09-14 17:01:32 -0700
committerDaisuke Miyakawa <dmiyakawa@google.com>2011-09-14 17:01:32 -0700
commit4b80d252210137df98bb393b290725f93877b00c (patch)
tree9da99ea37e392a4db4c0365087555aa0bf05dffc /common
parent5753143e03a6b8a61b2ffd6cbb04f1d54f406956 (diff)
downloadandroid_frameworks_ex-4b80d252210137df98bb393b290725f93877b00c.tar.gz
android_frameworks_ex-4b80d252210137df98bb393b290725f93877b00c.tar.bz2
android_frameworks_ex-4b80d252210137df98bb393b290725f93877b00c.zip
Use ICS version code
Bug: 5047678 Change-Id: I748525684b82f16d7a799b035ad2cfed22fa02d9
Diffstat (limited to 'common')
-rw-r--r--common/java/com/android/common/contacts/DataUsageStatUpdater.java9
1 files changed, 3 insertions, 6 deletions
diff --git a/common/java/com/android/common/contacts/DataUsageStatUpdater.java b/common/java/com/android/common/contacts/DataUsageStatUpdater.java
index 6ff3807..273ae61 100644
--- a/common/java/com/android/common/contacts/DataUsageStatUpdater.java
+++ b/common/java/com/android/common/contacts/DataUsageStatUpdater.java
@@ -200,12 +200,9 @@ public class DataUsageStatUpdater {
boolean successful = false;
- // From ICS we can use per-contact-method structure. We'll check if the device supports it
- // and call the API.
- //
- // STOPSHIP: Use Build.VERSION.SDK_INT when we're sure ICS has correct SDK version
- // (bug 5047678)
- if (TextUtils.equals("IceCreamSandwich", Build.VERSION.RELEASE)) {
+ // From ICS (SDK_INT 14) we can use per-contact-method structure. We'll check if the device
+ // supports it and call the API.
+ if (Build.VERSION.SDK_INT >= 14) {
if (dataIds.isEmpty()) {
if (Log.isLoggable(TAG, Log.DEBUG)) {
Log.d(TAG, "Given list for data IDs is null. Ignoring.");